@@ -43,14 +43,17 @@ OC.L10N.register(
     "Cancel" : "Kanselleer",
     "General" : "Algemeen",
     "Add mail account" : "Voeg posrekening toe",
+    "Newest first" : "Nuutste eerste",
+    "Oldest first" : "Oudste eerste",
     "Register" : "Registreer",
-    "About" : "Aangaande",
+    "Security" : "Sekuriteit",
     "Keyboard shortcuts" : "Sneltoetse",
     "Archive" : "Argief",
     "Delete" : "Skrap",
     "Search" : "Soek",
     "Send" : "Stuur",
     "Refresh" : "Verfris",
+    "About" : "Aangaande",
     "No certificate" : "Geen sertifikaat",
     "Certificate updated" : "Sertifikaat bygewerk",
     "Could not update certificate" : "Kon nie sertifikaat bywerk nie",
@@ -60,9 +63,7 @@ OC.L10N.register(
     "From" : "Van",
     "Select account" : "Kies rekening",
     "To" : "Aan",
-    "Contact or email address …" : "Kontak of e-posadres …",
     "Subject" : "Onderwerp",
-    "Write message …" : "Skryf boodskap…",
     "Send now" : "Stuur nou",
     "Tomorrow morning" : "Môreoggend",
     "Tomorrow afternoon" : "Môremiddag",
@@ -96,7 +97,6 @@ OC.L10N.register(
     "Remove account" : "Verwyder rekening",
     "Add folder" : "Voeg 'n gids by",
     "Saving" : "Stoor tans",
-    "Loading …" : "Laai …",
     "New message" : "Nuwe boodskap",
     "Reply" : "Antwoord",
     "Retry" : "Herprobeer",
@@ -133,6 +133,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
     "The link leads to %s" : "Die skakel lei na %s",
-    "Accounts" : "Accounts"
+    "Accounts" : "Accounts",
+    "Contact or email address …" : "Kontak of e-posadres …",
+    "Write message …" : "Skryf boodskap…",
+    "Loading …" : "Laai …"
 },
 "nplurals=2; plural=(n != 1);");
