@@ -41,29 +41,39 @@ OC.L10N.register(
     "Email address" : "Адрас электроннай пошты",
     "Cancel" : "Скасаваць",
     "General" : "Агульныя",
+    "Appearance" : "Знешні выгляд",
     "Layout" : "Макет",
     "List" : "Спіс",
     "Sorting" : "Сартаванне",
+    "Newest first" : "Спачатку новыя",
+    "Oldest first" : "Спачатку старыя",
     "Privacy and security" : "Прыватнасць і бяспека",
+    "Security" : "Бяспека",
     "S/MIME" : "S/MIME",
-    "About" : "Аб праграме",
+    "Manage certificates" : "Кіраванне сертыфікатамі",
+    "Step 1" : "Крок 1",
+    "Install the browser extension" : "Усталюйце пашырэнне для браўзера",
+    "Step 2" : "Крок 2",
+    "Enable for the current domain" : "Уключыце для бягучага дамена",
     "Keyboard shortcuts" : "Спалучэнні клавіш",
     "Archive" : "Архіў",
     "Delete" : "Выдаліць",
     "Search" : "Пошук",
     "Send" : "Адправіць",
     "Refresh" : "Абнавіць",
+    "About" : "Аб праграме",
     "Ok" : "ОК",
     "From" : "Ад",
     "Select account" : "Выберыце ўліковы запіс",
     "To" : "Каму",
     "Cc/Bcc" : "Cc/Bcc",
+    "Contact or email address …" : "Кантакт або email …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Тэма",
-    "Subject …" : "Тэма …",
-    "Write message …" : "Напішыце паведамленне …",
-    "Saving draft …" : "Захаванне чарнавіка …",
+    "Subject …" : "Тэма …",
+    "Write message …" : "Напішыце паведамленне …",
+    "Saving draft …" : "Захаванне чарнавіка …",
     "Error saving draft" : "Памылка пры захаванні чарнавіка",
     "Draft saved" : "Чарнавік захаваны",
     "Save draft" : "Захаваць чарнавік",
@@ -114,6 +124,7 @@ OC.L10N.register(
     "Yesterday" : "Учора",
     "Last week" : "Мінулы тыдзень",
     "Last month" : "Мінулы месяц",
+    "Loading messages …" : "Загрузка паведамленняў …",
     "Choose target folder" : "Выберыце мэтавую папку",
     "Other" : "Іншае",
     "Forward" : "Пераслаць",
@@ -134,7 +145,7 @@ OC.L10N.register(
     "Move down" : "Перамясціць уніз",
     "Show all folders" : "Паказаць усе папкі",
     "_{total} message_::_{total} messages_" : ["{total} паведамленне","{total} паведамленні","{total} паведамленняў","{total} паведамленняў"],
-    "Loading …" : "Загрузка …",
+    "Loading …" : "Загрузка …",
     "Clear folder" : "Ачысціць папку",
     "Delete folder" : "Выдаліць папку",
     "Delete folder {name}" : "Выдаліць папку {name}",
@@ -157,6 +168,7 @@ OC.L10N.register(
     "Message" : "Паведамленне",
     "New Contact" : "Новы кантакт",
     "Copy to clipboard" : "Капіяваць у буфер абмену",
+    "Contact name …" : "Імя кантакту …",
     "Add" : "Дадаць",
     "Clear" : "Ачысціць",
     "Search in folder" : "Пошук у папцы",
@@ -167,6 +179,11 @@ OC.L10N.register(
     "Tags" : "Тэгі",
     "Last 7 days" : "Апошнія 7 дзён",
     "Custom" : "Карыстальніцкі",
+    "Signature …" : "Подпіс …",
+    "Saving new tag name …" : "Захаванне новай назвы тэга …",
+    "Delete tag" : "Выдаліць тэг",
+    "Add tag" : "Дадаць тэг",
+    "Saving tag …" : "Захаванне тэга …",
     "Task created" : "Заданне створана",
     "Could not create task" : "Не ўдалося стварыць заданне",
     "No calendars with task list support" : "Няма календароў з падтрымкай спісаў заднняў",
@@ -189,8 +206,14 @@ OC.L10N.register(
     "Move into folder" : "Перамясціць у папку",
     "Stop" : "Спыніць",
     "Delete filter" : "Выдаліць фільтр",
+    "New filter" : "Новы фільтр",
+    "Filter is active" : "Фільтр актыўны",
+    "Filter is not active" : "Фільтр неактыўны",
     "Help" : "Даведка",
+    "Enter subject" : "Увядзіце тэму",
     "Actions" : "Дзеянні",
+    "Priority" : "Прыярытэт",
+    "Enable filter" : "Уключыць фільтр",
     "Tag" : "Тэг",
     "delete" : "выдаліць",
     "Edit" : "Рэдагаваць",
@@ -242,6 +265,10 @@ OC.L10N.register(
     "Could not load the message" : "Не ўдалося загрузіць паведамленне",
     "Error loading message" : "Памылка пры загрузцы паведамлення",
     "Forwarding to %s" : "Перасыланне да %s",
-    "Accounts" : "Уліковыя запісы"
+    "Accounts" : "Уліковыя запісы",
+    "Subject …" : "Тэма …",
+    "Write message …" : "Напішыце паведамленне …",
+    "Saving draft …" : "Захаванне чарнавіка …",
+    "Loading …" : "Загрузка …"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
