@@ -90,10 +90,14 @@ OC.L10N.register(
     "Mail settings" : "Настройки на пощата",
     "General" : "Общи",
     "Add mail account" : "Добавяне на профил",
+    "Appearance" : "Изглед",
     "List" : "Списък",
+    "Newest first" : "Първо най-новият",
+    "Oldest first" : "Първо най-старият",
     "Register" : "Регистрация",
     "Shared with me" : "Споделено с мен",
-    "About" : "Относно",
+    "Security" : "Сигурност",
+    "Manage certificates" : "Управление на сертификатите",
     "Keyboard shortcuts" : "Бързи клавиши",
     "Compose new message" : "Създай ново съобщение",
     "Newer message" : "Следващо съобщение",
@@ -105,6 +109,7 @@ OC.L10N.register(
     "Search" : "Търси",
     "Send" : "Изпрати",
     "Refresh" : "Опресняване",
+    "About" : "Относно",
     "Ok" : "Добре",
     "No certificate" : "Няма сертификат",
     "Certificate updated" : "Актуализиран е сертификат",
@@ -127,16 +132,12 @@ OC.L10N.register(
     "Select account" : "Избери профил",
     "To" : "До",
     "Select recipient" : "Избор на получател",
-    "Contact or email address …" : "Контакт или имейл адрес...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Тема",
-    "Subject …" : "Тема...",
     "This message came from a noreply address so your reply will probably not be read." : "Това съобщение дойде от адрес с настройка без отговор, така че отговорът ви вероятно няма да бъде прочетен.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Следните получатели нямат  S/MIME сертификат: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Следните получатели нямат PGP ключ: {recipients}.",
-    "Write message …" : "Писане на съобщение ...",
-    "Saving draft …" : "Записване на чернова …",
     "Error saving draft" : "Грешка при запазване на черновата",
     "Draft saved" : "Черновата е записана",
     "Save draft" : "Запиши чернова",
@@ -246,7 +247,6 @@ OC.L10N.register(
     "Today" : "Днес",
     "Last week" : "Миналата седмица",
     "Last month" : "Миналия месец",
-    "Loading messages …" : "Зареждане на съобщения ...",
     "Choose target folder" : "Избор на папка",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
@@ -301,7 +301,6 @@ OC.L10N.register(
     "Collapse folders" : "Свиване на папки",
     "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
-    "Loading …" : "Зарежда …",
     "All messages in mailbox will be deleted." : "Всички съобщения в пощенската кутия ще бъдат изтрити.",
     "Clear mailbox {name}" : "Изчистване на пощенска кутия {name}",
     "Delete folder" : "Изтриване на папка",
@@ -346,7 +345,6 @@ OC.L10N.register(
     "Add to Contact" : "Добавяне към контакт",
     "New Contact" : "Нов контакт",
     "Copy to clipboard" : "Копиране в клипборда",
-    "Contact name …" : "Име за контакт …",
     "Add" : "Добавяне",
     "Show less" : "Покажи по-малко",
     "Show more" : "Покажи повече",
@@ -372,13 +370,11 @@ OC.L10N.register(
     "Sieve Password" : "Парола за Сито",
     "Save sieve settings" : "Записване на настройките на ситото",
     "Save sieve script" : "Записване на скрипт за сито",
-    "Signature …" : "Подпис…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Подписът ви е по-голям от 2 MB. Това може да се отрази на работата на  вашия редактор.",
     "Save signature" : "Запис на подпис",
     "Place signature above quoted text" : "Поставяне на подпис над цитирания текст",
     "Message source" : "Източник на съобщение",
     "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
-    "Saving new tag name …" : "Запазва се името на нов етикет …",
     "Delete tag" : "Изтрий таг",
     "Set tag" : "Задаване на етикет",
     "Unset tag" : "Отмяна на етикет",
@@ -387,7 +383,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Възникна грешка, не може да се създаде етикет.",
     "Add default tags" : "Добавяне на етикети по подразбиране",
     "Add tag" : "Добавяне на етикет",
-    "Saving tag …" : "Записване на етикет ...",
     "Could not load your message thread" : " Нишката на вашето съобщение не можа да се зареди",
     "The thread doesn't exist or has been deleted" : "Нишката не съществува или е била изтрита",
     "Loading thread" : "Зареждане на нишка",
@@ -490,6 +485,7 @@ OC.L10N.register(
     "Provisioning domain" : "Осигуряващ домейн",
     "Email address template" : "Шаблон за имейл адрес",
     "IMAP" : "IMAP",
+    "User" : "Потребител",
     "Host" : "Хост",
     "Port" : "Порт",
     "SMTP" : "SMTP",
@@ -523,6 +519,7 @@ OC.L10N.register(
     "Private key (optional)" : "Частен ключ (по избор)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Частният ключ е необходим само ако възнамерявате да изпращате подписани и криптирани имейли, като използвате този сертификат.",
     "Submit" : "Изпращане",
+    "Group" : "Група",
     "Shared" : "Споделен",
     "Shares" : "Споделени",
     "Insert" : "Вмъкване",
@@ -567,6 +564,16 @@ OC.L10N.register(
     "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
     "Trusted senders" : "Доверени податели",
-    "Manage S/MIME certificates" : "Управление на S/MIME сертификати"
+    "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
+    "Contact or email address …" : "Контакт или имейл адрес...",
+    "Subject …" : "Тема...",
+    "Write message …" : "Писане на съобщение ...",
+    "Saving draft …" : "Записване на чернова …",
+    "Loading messages …" : "Зареждане на съобщения ...",
+    "Loading …" : "Зарежда …",
+    "Contact name …" : "Име за контакт …",
+    "Signature …" : "Подпис…",
+    "Saving new tag name …" : "Запазва се името на нов етикет …",
+    "Saving tag …" : "Записване на етикет ..."
 },
 "nplurals=2; plural=(n != 1);");
