@@ -117,13 +117,17 @@ OC.L10N.register(
     "General" : "Generelt",
     "Add mail account" : "Tilføj mail konto",
     "Settings for:" : "Indstillinger for:",
+    "Appearance" : "Udseende",
     "Layout" : "Layout",
     "List" : "Liste",
     "Vertical split" : "Vertikal opdeling",
     "Horizontal split" : "Horisontal opdeling",
     "Sorting" : "Sortering",
     "Newest first" : "Nyeste først",
+    "Oldest first" : "Ældste først",
     "Show all messages in thread" : "Vis alle beskeder i tråde",
+    "Top" : "Top",
+    "Bottom" : "Bund",
     "Search in body" : "Søg i body",
     "Gravatar settings" : "Gravatar indstillinger",
     "Mailto" : "Mail til",
@@ -135,9 +139,13 @@ OC.L10N.register(
     "Security" : "Sikkerhed",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhæv eksterne e-mailadresser ved at aktivere denne funktion. Håndter dine interne adresser og domæner, for at sikre at genkendte kontakter forbliver ikke markerede.",
     "S/MIME" : "S/MIME",
+    "Manage certificates" : "Håndter certifikater",
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain." : "Mailvelope er aktiveret for det aktuelle domæne.",
-    "About" : "Om",
+    "Step 1" : "Trin 1",
+    "Install the browser extension" : "Installér browserudvidelsen",
+    "Step 2" : "Trin 2",
+    "Enable for the current domain" : "Aktivér for det aktuelle domæne",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Compose new message" : "Skriv en ny meddelelse",
     "Newer message" : "Nyere besked",
@@ -149,6 +157,8 @@ OC.L10N.register(
     "Search" : "Søg",
     "Send" : "Send",
     "Refresh" : "Opdatér",
+    "About" : "Om",
+    "Mail version: {version}" : "Mail version: {version}",
     "Title of the text block" : "Titel på ny tekstblok",
     "Content of the text block" : "Indhold i tekstblok",
     "Ok" : "OK",
@@ -175,16 +185,15 @@ OC.L10N.register(
     "To" : "Til",
     "Cc/Bcc" : "Cc/Bcc",
     "Select recipient" : "Vælg modtager",
-    "Contact or email address …" : "Kontakt eller email…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Emne",
-    "Subject …" : "Emne…",
+    "Subject …" : "Emne …",
     "This message came from a noreply address so your reply will probably not be read." : "Denne meddelelse kom fra en svar-ikke adresse. Dit svar vil sansynligvis ikke blive læst. ",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Følgende modtagere har ikke et S/MIME-certifikat: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Følgende modtagere har ikke en PGP nøgle: {recipients}.",
-    "Write message …" : "Skriv en besked…",
-    "Saving draft …" : "Gemmer kladde…",
+    "Write message …" : "Skriv besked …",
+    "Saving draft …" : "Gemmer kladde …",
     "Error saving draft" : "Fejl ved lagring af kladde",
     "Draft saved" : "Kladde gemt",
     "Save draft" : "Gem kladde",
@@ -334,7 +343,7 @@ OC.L10N.register(
     "Last week" : "Seneste uge",
     "Last month" : "Sidste måned",
     "Could not open folder" : "Kunne ikke åbne mappe",
-    "Loading messages …" : "Indlæser beskeder...",
+    "Loading messages …" : "Indlæser beskeder …",
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekserer dine beskeder. Dette kan tage en smule længere for større mapper.",
     "Choose target folder" : "Vælg destinationsmappe",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
@@ -360,6 +369,7 @@ OC.L10N.register(
     "View source" : "Vis kildekode",
     "Print message" : "Udskriv besked",
     "Create mail filter" : "Opret mailfilter",
+    "Message body" : "Hovedbesked",
     "Unnamed" : "Unavngiven",
     "Embedded message" : "Indlejret besked",
     "Attachment saved to Files" : "Vedhæftning gemt til Filer",
@@ -400,7 +410,7 @@ OC.L10N.register(
     "Collapse folders" : "Fold mapper sammen",
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulæst ud af {total}","{unread} ulæst ud af {total}"],
-    "Loading …" : "Indlæser…",
+    "Loading …" : "Indlæser …",
     "All messages in mailbox will be deleted." : "Alle beskeder i din mailboks bliver slettet.",
     "Clear mailbox {name}" : "Ryd postkasse {name}",
     "Clear folder" : "Ryd mappe",
@@ -458,7 +468,6 @@ OC.L10N.register(
     "Add to Contact" : "Tilføj til kontakt",
     "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopier til udklipsholder",
-    "Contact name …" : "Kontaktnavn ...",
     "Add" : "Tilføj",
     "Show less" : "Vis mindre",
     "Show more" : "Vis mere",
@@ -489,10 +498,8 @@ OC.L10N.register(
     "Sieve credentials" : "Sieve legitimationsoplysninger",
     "IMAP credentials" : "IMAP legitimationsoplysninger",
     "Custom" : "Brugerdefineret",
-    "Signature …" : "Underskrift …",
     "Save signature" : "Gem underskrift",
     "Message source" : "Beskedens kildekode",
-    "Saving new tag name …" : "Gemmer nyt tag navn ...",
     "Tag already exists" : "Mærket eksisterer allerede",
     "Add tag" : "Tilføj tag",
     "Print" : "Udskriv",
@@ -606,6 +613,15 @@ OC.L10N.register(
     "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
     "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope er en browser udvidelse som giver mulighed for let OpenPGP kryptering og dekryptering til e-mails.",
     "Step 1: Install Mailvelope browser extension" : "Trin 1: Installer Mailvelope browser udvidelse",
-    "Step 2: Enable Mailvelope for the current domain" : "Trin 2: Aktiver Mailvelope for det aktuelle domæne"
+    "Step 2: Enable Mailvelope for the current domain" : "Trin 2: Aktiver Mailvelope for det aktuelle domæne",
+    "Contact or email address …" : "Kontakt eller email…",
+    "Subject …" : "Emne…",
+    "Write message …" : "Skriv en besked…",
+    "Saving draft …" : "Gemmer kladde…",
+    "Loading messages …" : "Indlæser beskeder...",
+    "Loading …" : "Indlæser…",
+    "Contact name …" : "Kontaktnavn ...",
+    "Signature …" : "Underskrift …",
+    "Saving new tag name …" : "Gemmer nyt tag navn ..."
 },
 "nplurals=2; plural=(n != 1);");
