@@ -133,7 +133,6 @@ OC.L10N.register(
     "S/MIME" : "S/MIME",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Características de asistencia",
-    "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -145,6 +144,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "About" : "Acerca",
     "No certificate" : "Sin certificado",
     "Certificate updated" : "Certificado actualizado",
     "Could not update certificate" : "No se pudo actualizar el certificado",
@@ -169,16 +169,12 @@ OC.L10N.register(
     "To" : "Para",
     "Cc/Bcc" : "Cc/Cco",
     "Select recipient" : "Seleccionar destinatario",
-    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
     "Cc" : "Cc",
     "Bcc" : "Cco",
     "Subject" : "Asunto",
-    "Subject …" : "Asunto...",
     "This message came from a noreply address so your reply will probably not be read." : "Este mensaje vino de una dirección \"no-responder\", por lo que tu respuesta podría no ser leída.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Los siguientes destinatarios no tienen un certificado S/MIME: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Los siguientes destinatarios no tienen una clave PGP: {recipients}.",
-    "Write message …" : "Redactar mensaje...",
-    "Saving draft …" : "Guardando borrador...",
     "Error saving draft" : "Error guardando el borrador",
     "Draft saved" : "Borrador guardado",
     "Save draft" : "Guardar borrador",
@@ -291,7 +287,6 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Last week" : "Semana pasada",
     "Last month" : "Mes pasado",
-    "Loading messages …" : "Cargando mensajes...",
     "Choose target folder" : "Elegir carpeta destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
     "Follow up" : "Seguimiento",
@@ -318,7 +313,6 @@ OC.L10N.register(
     "Move down" : "Mover abajo",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
-    "Loading …" : "Cargando …",
     "Delete folder" : "Eliminar carpeta",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
@@ -406,6 +400,12 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
     "Trusted senders" : "Remitentes de confianza",
     "Internal addresses" : "Direcciones internas",
-    "Manage S/MIME certificates" : "Administrar certificados S/MIME"
+    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
+    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
+    "Subject …" : "Asunto...",
+    "Write message …" : "Redactar mensaje...",
+    "Saving draft …" : "Guardando borrador...",
+    "Loading messages …" : "Cargando mensajes...",
+    "Loading …" : "Cargando …"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
