@@ -113,8 +113,11 @@ OC.L10N.register(
     "Add alias" : "Lisa alias",
     "Create alias" : "Loo alias",
     "Cancel" : "Katkesta",
+    "Search the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
     "Activate" : "Lülita sisse",
+    "Determine importance using machine learning" : "Määra olulisus masinõppe abil",
     "Remind about messages that require a reply but received none" : "Tuleta mulle meelde kirju, mis eeldavad vastust, kui pole seda veel saanud",
+    "Highlight external addresses" : "Tõsta välised aadressid esile",
     "Could not update preference" : "Eelistust polnud võimalik muuta",
     "Mail settings" : "E-kirjade seadistused",
     "General" : "Üldine",
@@ -130,24 +133,36 @@ OC.L10N.register(
     "Oldest first" : "Vanemad eespool",
     "Message view mode" : "Kirjade vaate liik",
     "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
+    "When off, only the selected message will be shown" : "Kui eelistus pole kasutusel, siis näidatakse vaid valitud kirja",
+    "Reply position" : "Vastuse asukoht",
     "Top" : "Üleval",
     "Bottom" : "All",
     "Search in body" : "Otsi kirja sisust",
     "Gravatar settings" : "Gravatari seadistused",
+    "Avatars from Gravatar and favicons" : "Favikonid ja tunnuspildid teenusest Gravatar",
     "Mailto" : "Mailto",
+    "Set as default mail app" : "Määra vaikimisi e-postirakenduseks",
     "Register" : "Registreeru",
     "Text blocks" : "Tekstiplokid",
+    "Reusable pieces of text that can be inserted in messages" : "Teksti kasutatavad osad, misa saad kirjadesse lisada",
     "New text block" : "Uus tekstiplokk",
     "Shared with me" : "Jagatud minuga",
     "Privacy and security" : "Privaatsus ja turvalisus",
+    "Data collection" : "Andmete kogumine",
+    "Allow the app to collect and process data locally to adapt to your preferences." : "Luba rakendusel kohalikus seadmes andmeid koguda ja töödelda ning lasta kohanduda sinu eelistustega.",
+    "Always show images from" : "Alati näita pilte saatjalt",
     "Security" : "Turvalisus",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Selle valikuga tõstetakse välised e-posti aadressid esile, hallatakse sinu jaoks serveri sisemisi aadresse ja domeene. Nii tagatakse, et sinu poolt kinnitatud kontaktid jäävad esiletõstmata.",
     "S/MIME" : "S/MIME",
+    "Manage certificates" : "Halda sertifikaate",
     "Mailvelope" : "Mailvelope",
+    "A browser extension that enables easy OpenPGP encryption and decryption of emails" : "Brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
     "Mailvelope is enabled for the current domain." : "Mailvelope on selle domeeni puhul kasutusel.",
+    "Step 1" : "1. samm",
+    "Install the browser extension" : "Paigalda veebibrauseri laiendus/lisamoodul",
+    "Step 2" : "2. samm",
+    "Enable for the current domain" : "Luba  kasutamine selle domeeni puhul",
     "Assistance features" : "Abilise funktsionaalsused",
-    "About" : "Rakenduse teave",
-    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
     "Keyboard shortcuts" : "Klaviatuuri kiirklahvid",
     "Compose new message" : "Koosta uus kiri",
     "Newer message" : "Uuem kiri",
@@ -159,6 +174,9 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
+    "About" : "Rakenduse teave",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
+    "Mail version: {version}" : "E-postirakenduse versioon: {version}",
     "Title of the text block" : "Tekstiploki pealkiri",
     "Content of the text block" : "Tekstiploki sisu",
     "Ok" : "Sobib",
@@ -186,16 +204,16 @@ OC.L10N.register(
     "To" : "Saaja",
     "Cc/Bcc" : "Cc/Bcc",
     "Select recipient" : "Vali kirja saaja",
-    "Contact or email address …" : "Kontakt või e-posti aadress…",
+    "Contact or email address …" : "Kontakt või e-posti aadress…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Teema",
-    "Subject …" : "Teema…",
+    "Subject …" : "Teema…",
     "This message came from a noreply address so your reply will probably not be read." : "See kiri on saadetud aadressilt, kuhu vastuseid ei oodata ja seega sinu saadetud vastust ilmselt mitte keegi ei loe.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Järgnevatel saajatel puudub S/MIME sertifikaat: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Järgnevatel saajatel puudub PGP võti: {recipients}.",
-    "Write message …" : "Koosta kiri…",
-    "Saving draft …" : "Salvestan kavandit…",
+    "Write message …" : "Koosta kiri…",
+    "Saving draft …" : "Salvestan kavandit…",
     "Error saving draft" : "Viga kavandi salvestamisel",
     "Draft saved" : "Kavand on salvestatud",
     "Save draft" : "Salvesta kavand",
@@ -349,7 +367,7 @@ OC.L10N.register(
     "Last week" : "Eelmisel nädalal",
     "Last month" : "Eelmisel kuul",
     "Could not open folder" : "Kausta avamine ei õnnestunud",
-    "Loading messages …" : "Laadin kirju…",
+    "Loading messages …" : "Laadin kirju…",
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
@@ -421,7 +439,7 @@ OC.L10N.register(
     "Collapse folders" : "Ahenda kaustad",
     "_{total} message_::_{total} messages_" : ["{total} kiri","{total} kirja"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
-    "Loading …" : "Laadin...",
+    "Loading …" : "Andmed on laadimisel…",
     "All messages in mailbox will be deleted." : "Kõik kirjad sellest postkastist  kustutatakse.",
     "Clear mailbox {name}" : "Tühjenda postkast: {name}",
     "Clear folder" : "Tühjenda kaust",
@@ -497,7 +515,7 @@ OC.L10N.register(
     "Add to Contact" : "Lisa kontaktile",
     "New Contact" : "Uus kontakt",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
-    "Contact name …" : "Kontakti nimi…",
+    "Contact name …" : "Kontakti nimi…",
     "Add" : "Lisa",
     "Show less" : "Näita vähem",
     "Show more" : "Näita rohkem",
@@ -539,14 +557,14 @@ OC.L10N.register(
     "Save sieve settings" : "Salvesta Sieve'i seadistused",
     "The syntax seems to be incorrect:" : "Süntaks tundub olema vigane:",
     "Save sieve script" : "Salvesta Sieve skript",
-    "Signature …" : "Allkiri…",
+    "Signature …" : "Allkiri…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Sinu e-kirjade allkiri on suurem, kui 2 MB ja see võib mõjutada kirjutamisliidese jõudlust.",
     "Save signature" : "Salvesta allkiri",
     "Place signature above quoted text" : "Aseta allkiri tsiteeritud teksti ette",
     "Message source" : "Kirja lähtekood",
     "An error occurred, unable to rename the tag." : "Tekkis viga ning sildi nime ei saanud muuta.",
     "Edit name or color" : "Muuda nime või värvi",
-    "Saving new tag name …" : "Salvestan sildi uut nime…",
+    "Saving new tag name …" : "Salvestan sildi uut nime…",
     "Delete tag" : "Kustuta silt",
     "Set tag" : "Lisa silt kirjale",
     "Unset tag" : "Eemalda silt kirjalt",
@@ -556,7 +574,7 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Tekkis viga ning silti ei saanud luua.",
     "Add default tags" : "Lisa vaikimisi sildid",
     "Add tag" : "Lisa silt",
-    "Saving tag …" : "Salvestan silti…",
+    "Saving tag …" : "Salvestan silti…",
     "Task created" : "Ülesanne on koostatud",
     "Could not create task" : "Ülesande koostamine ei õnnestunud",
     "No calendars with task list support" : "Pole ülesannete toega kalendrit",
@@ -831,6 +849,16 @@ OC.L10N.register(
     "Manage S/MIME certificates" : "Halda S/MIME sertifikaate",
     "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope on brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
     "Step 1: Install Mailvelope browser extension" : "1. samm: Paigalda Mailvelope'i brauserilaiendus",
-    "Step 2: Enable Mailvelope for the current domain" : "2. samm: Võta Mailvelope selle domeeni puhul kasutusele"
+    "Step 2: Enable Mailvelope for the current domain" : "2. samm: Võta Mailvelope selle domeeni puhul kasutusele",
+    "Contact or email address …" : "Kontakt või e-posti aadress…",
+    "Subject …" : "Teema…",
+    "Write message …" : "Koosta kiri…",
+    "Saving draft …" : "Salvestan kavandit…",
+    "Loading messages …" : "Laadin kirju…",
+    "Loading …" : "Laadin...",
+    "Contact name …" : "Kontakti nimi…",
+    "Signature …" : "Allkiri…",
+    "Saving new tag name …" : "Salvestan sildi uut nime…",
+    "Saving tag …" : "Salvestan silti…"
 },
 "nplurals=2; plural=(n != 1);");
