@@ -135,7 +135,6 @@ OC.L10N.register(
     "Manage certificates" : "Kudeatu ziurtagiriak",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Laguntzailearen aukerak",
-    "About" : "Honi buruz",
     "Keyboard shortcuts" : "Teklatuaren lasterbideak",
     "Compose new message" : "Idatzi mezu berria",
     "Newer message" : "Mezu berriagoa",
@@ -147,6 +146,7 @@ OC.L10N.register(
     "Search" : "Bilatu",
     "Send" : "Bidali",
     "Refresh" : "Freskatu",
+    "About" : "Honi buruz",
     "Ok" : "Ados",
     "No certificate" : "Ziurtagiririk ez",
     "Certificate updated" : "Ziurtagiria eguneratu da",
@@ -172,16 +172,12 @@ OC.L10N.register(
     "To" : "Nori",
     "Cc/Bcc" : "Cc/Bcc",
     "Select recipient" : "Hautatu hartzailea",
-    "Contact or email address …" : "Kontaktua edo posta helbidea…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Gaia",
-    "Subject …" : "Gaia…",
     "This message came from a noreply address so your reply will probably not be read." : "Mezu hau noreply helbide batetik dator, beraz, ziur aski, zure erantzuna ez dute irakurriko.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Hartzaile hauek ez dute S/MIME ziurtagiririk: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : " \nHartzaile hauek ez dute PGP gakorik: {recipients}.",
-    "Write message …" : "Idatzi mezua...",
-    "Saving draft …" : "Zirriborroa gordetzen...",
     "Error saving draft" : "Errore bat gertatu da zirriborroa gordetzean",
     "Draft saved" : "Zirriborroa gorde egin da",
     "Save draft" : "Gorde zirriborroa",
@@ -315,7 +311,6 @@ OC.L10N.register(
     "Today" : "Gaur",
     "Last week" : "Joan den astean",
     "Last month" : "Joan den hilabetean",
-    "Loading messages …" : "Mezuak kargatzen ...",
     "Choose target folder" : "Aukeratu helburuko karpeta",
     "No more submailboxes in here" : "Azpipostontzi gehiagorik ez hemen",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Mezuak automatikoki markatuko dira garrantzitsu bezala kontuan izanda zein mezurekin aritu zaren interakzioan edo zein markatu dituzun garratzitsu gisa. Hasieran garrantzia eskuz aldatu beharko duzu sistemari irakasteko, baina denborarekin hobetuko du.",
@@ -385,7 +380,6 @@ OC.L10N.register(
     "Collapse folders" : "Bildu karpetak",
     "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
-    "Loading …" : "Kargatzen...",
     "All messages in mailbox will be deleted." : "Postontziko mezu guztiak ezabatuko dira.",
     "Clear mailbox {name}" : "Garbitu {name} postontzia",
     "The folder and all messages in it will be deleted." : " \nKarpeta eta bertan dauden mezu guztiak ezabatuko dira.",
@@ -449,7 +443,6 @@ OC.L10N.register(
     "Add to Contact" : "Gehitun kontaktuetara",
     "New Contact" : "Kontaktu berria",
     "Copy to clipboard" : "Kopiatu arbelera",
-    "Contact name …" : "Kontaktu izena ...",
     "Add" : "Gehitu",
     "Show less" : "Erakutsi gutxiago",
     "Show more" : "Erakutsi gehiago",
@@ -489,14 +482,12 @@ OC.L10N.register(
     "Save sieve settings" : "Gorde sieve ezarpenak",
     "The syntax seems to be incorrect:" : "Sintaxia baliogabea dirudi:",
     "Save sieve script" : "Gorde sieve scripta",
-    "Signature …" : "Sinadura...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Zure sinadurak 2MB baino gehiago ditu. Honek editorearen errendimendua gutxitu dezake.",
     "Save signature" : "Gorde sinadura",
     "Place signature above quoted text" : "Jarri sinadura aipatutako testuaren gainean",
     "Message source" : "Mezuaren iturburua",
     "An error occurred, unable to rename the tag." : "Errore bat gertatu da, ezin izan zaio etiketa aldatu.",
     "Edit name or color" : "Editatu izena edo kolorea",
-    "Saving new tag name …" : "Etiketa-izen berria gordetzen ...",
     "Delete tag" : "Ezabatu etiketa",
     "Set tag" : "Ezarri etiketa",
     "Unset tag" : "Ezarri gabeko etiketa",
@@ -506,7 +497,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Errore bat gertatu da, ezin da etiketa sortu.",
     "Add default tags" : "Gehitu etiketa lehenetsiak",
     "Add tag" : "Gehitu etiketa",
-    "Saving tag …" : "Etiketa gordetzen",
     "Task created" : "Eginkizuna sortuta",
     "Could not create task" : "Ezin izan da eginkizuna sortu",
     "No calendars with task list support" : "Ez dago eginkizun-zerrendarik onartzen duen egutegirik",
@@ -744,6 +734,16 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
     "Trusted senders" : "Bidaltzaile fidagarriak",
     "Internal addresses" : "Barneko helbideak",
-    "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak"
+    "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak",
+    "Contact or email address …" : "Kontaktua edo posta helbidea…",
+    "Subject …" : "Gaia…",
+    "Write message …" : "Idatzi mezua...",
+    "Saving draft …" : "Zirriborroa gordetzen...",
+    "Loading messages …" : "Mezuak kargatzen ...",
+    "Loading …" : "Kargatzen...",
+    "Contact name …" : "Kontaktu izena ...",
+    "Signature …" : "Sinadura...",
+    "Saving new tag name …" : "Etiketa-izen berria gordetzen ...",
+    "Saving tag …" : "Etiketa gordetzen"
 },
 "nplurals=2; plural=(n != 1);");
