@@ -107,7 +107,6 @@ OC.L10N.register(
     "Register" : "ثبت‌نام",
     "Shared with me" : "Shared with me",
     "Security" : "امنیتی",
-    "About" : "About",
     "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
     "Compose new message" : "نوشتن پیام جدید",
     "Newer message" : "پیام جدیدتر",
@@ -119,6 +118,7 @@ OC.L10N.register(
     "Search" : "جستجو",
     "Send" : "ارسال",
     "Refresh" : "تازه‌سازی",
+    "About" : "About",
     "Ok" : "باشه",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
@@ -140,16 +140,12 @@ OC.L10N.register(
     "From" : "از",
     "Select account" : "حساب را انتخاب کنید",
     "To" : "به",
-    "Contact or email address …" : "تماس با یا آدرس ایمیل ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "موضوع",
-    "Subject …" : "موضوع …",
     "This message came from a noreply address so your reply will probably not be read." : "این پیام از یک آدرس خیلی روشن آمده است بنابراین پاسخ شما احتمالاً خوانده نمی شود.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "The following recipients do not have a S/MIME certificate: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "The following recipients do not have a PGP key: {recipients}.",
-    "Write message …" : "ارسال پیام ...",
-    "Saving draft …" : "در حال ذخیره پیش نویس ...",
     "Error saving draft" : "Error saving draft",
     "Draft saved" : "پیش نویس ذخیره شد",
     "Save draft" : "Save draft",
@@ -268,7 +264,6 @@ OC.L10N.register(
     "Today" : "امروز.",
     "Last week" : "هفته گذشته",
     "Last month" : "ماه گذشته",
-    "Loading messages …" : "Loading messages …",
     "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
@@ -325,7 +320,6 @@ OC.L10N.register(
     "Collapse folders" : "پوشه ها را جمع کنید",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
-    "Loading …" : "بارگذاری …",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
     "Delete folder" : "حذف پوشه",
@@ -373,7 +367,6 @@ OC.L10N.register(
     "Add to Contact" : "Add to Contact",
     "New Contact" : "New Contact",
     "Copy to clipboard" : "کپی کردن به حافظه موقت",
-    "Contact name …" : "Contact name …",
     "Add" : "افزودن",
     "Show less" : "Show less",
     "Show more" : "Show more",
@@ -400,13 +393,11 @@ OC.L10N.register(
     "Save sieve settings" : "Save sieve settings",
     "The syntax seems to be incorrect:" : "The syntax seems to be incorrect:",
     "Save sieve script" : "Save sieve script",
-    "Signature …" : "امضا ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
     "Save signature" : "ذخیره امضا",
     "Place signature above quoted text" : "Place signature above quoted text",
     "Message source" : "Message source",
     "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
-    "Saving new tag name …" : "Saving new tag name …",
     "Set tag" : "Set tag",
     "Unset tag" : "Unset tag",
     "Tag name is a hidden system tag" : "Tag name is a hidden system tag",
@@ -414,7 +405,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
     "Add default tags" : "Add default tags",
     "Add tag" : "برچسب اضافه کنید",
-    "Saving tag …" : "Saving tag …",
     "Task created" : "Task created",
     "Could not create task" : "Could not create task",
     "No calendars with task list support" : "No calendars with task list support",
@@ -612,6 +602,16 @@ OC.L10N.register(
     "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
     "Trusted senders" : "Trusted senders",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates"
+    "Manage S/MIME certificates" : "Manage S/MIME certificates",
+    "Contact or email address …" : "تماس با یا آدرس ایمیل ...",
+    "Subject …" : "موضوع …",
+    "Write message …" : "ارسال پیام ...",
+    "Saving draft …" : "در حال ذخیره پیش نویس ...",
+    "Loading messages …" : "Loading messages …",
+    "Loading …" : "بارگذاری …",
+    "Contact name …" : "Contact name …",
+    "Signature …" : "امضا ...",
+    "Saving new tag name …" : "Saving new tag name …",
+    "Saving tag …" : "Saving tag …"
 },
 "nplurals=2; plural=(n > 1);");
