@@ -108,7 +108,6 @@ OC.L10N.register(
     "Security" : "Tietoturva",
     "S/MIME" : "S/MIME",
     "Manage certificates" : "Hallitse varmenteita",
-    "About" : "Tietoja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Compose new message" : "Uusi viesti",
     "Newer message" : "Uudempi",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
+    "About" : "Tietoja",
     "Title of the text block" : "Tekstilohkon otsikko",
     "Content of the text block" : "Tekstilohkon sisältö",
     "Ok" : "Ok",
@@ -142,16 +142,12 @@ OC.L10N.register(
     "Select account" : "Valitse tili",
     "To" : "Vastaanottaja",
     "Select recipient" : "Valitse vastaanottaja",
-    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Aihe",
-    "Subject …" : "Aihe…",
     "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Seuraavilla vastaanottajilla ei ole S/MIME-varmennetta: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
-    "Write message …" : "Kirjoita viesti…",
-    "Saving draft …" : "Tallennetaan luonnosta…",
     "Error saving draft" : "Virhe tallentaessa luonnosta",
     "Draft saved" : "Luonnos tallennettu",
     "Save draft" : "Tallenna luonnos",
@@ -270,7 +266,6 @@ OC.L10N.register(
     "Last week" : "Viime viikko",
     "Last month" : "Viime kuukausi",
     "Could not open folder" : "Kansiota ei voitu avata",
-    "Loading messages …" : "Ladataan viestejä …",
     "Choose target folder" : "Valitse kohdekansio",
     "Important info" : "Tärkeää tietoa",
     "Other" : "Muu",
@@ -326,7 +321,6 @@ OC.L10N.register(
     "Collapse folders" : "Supista kansiot",
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
-    "Loading …" : "Ladataan…",
     "All messages in mailbox will be deleted." : "Kaikki postilaatikon viestit poistetaan.",
     "Clear mailbox {name}" : "Tyhjennä postilaatikko {name}",
     "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
@@ -380,7 +374,6 @@ OC.L10N.register(
     "Add to Contact" : "Lisää yhteystietoon",
     "New Contact" : "Uusi yhteystieto",
     "Copy to clipboard" : "Kopioi leikepöydälle",
-    "Contact name …" : "Yhteystiedon nimi…",
     "Add" : "Lisää",
     "Show less" : "Näytä vähemmän",
     "Show more" : "Näytä enemmän",
@@ -402,21 +395,18 @@ OC.L10N.register(
     "Sieve Password" : "Sieve-salasana",
     "Save sieve settings" : "Tallenna sieve-asetukset",
     "The syntax seems to be incorrect:" : "Syntaksi vaikuttaa virheelliseltä:",
-    "Signature …" : "Allekirjoitus…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
     "Message source" : "Viestin lähde",
     "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
     "Edit name or color" : "Muokkaa nimeä tai väriä",
-    "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
     "Delete tag" : "Poista tunniste",
     "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
     "Tag already exists" : "Tunniste on jo olemassa",
     "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
     "Add default tags" : "Lisää oletustunnisteet",
     "Add tag" : "Lisää tunniste",
-    "Saving tag …" : "Tallennetaan tunnistetta…",
     "Task created" : "Tehtävä luotu",
     "Could not create task" : "Tehtävää ei voitu luoda",
     "Could not load your message thread" : "Viestiketjua ei voitu ladata",
@@ -613,6 +603,16 @@ OC.L10N.register(
     "Trusted senders" : "Luotetut lähettäjät",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
     "Step 1: Install Mailvelope browser extension" : "Vaihe 1: Asenna Mailvelope-selainlaajennus",
-    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle"
+    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle",
+    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
+    "Subject …" : "Aihe…",
+    "Write message …" : "Kirjoita viesti…",
+    "Saving draft …" : "Tallennetaan luonnosta…",
+    "Loading messages …" : "Ladataan viestejä …",
+    "Loading …" : "Ladataan…",
+    "Contact name …" : "Yhteystiedon nimi…",
+    "Signature …" : "Allekirjoitus…",
+    "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
+    "Saving tag …" : "Tallennetaan tunnistetta…"
 },
 "nplurals=2; plural=(n != 1);");
