@@ -63,7 +63,6 @@ OC.L10N.register(
     "Register" : "רישום",
     "Security" : "אבטחה",
     "Manage certificates" : "ניהול אישורים",
-    "About" : "אודות",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Compose new message" : "כתיבת הודעה חדשה",
     "Newer message" : "הודעה חדשה יותר",
@@ -75,20 +74,17 @@ OC.L10N.register(
     "Search" : "חיפוש",
     "Send" : "שליחה",
     "Refresh" : "רענון",
+    "About" : "אודות",
     "Ok" : "אישור",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "From" : "מאת",
     "Select account" : "בחר חשבון",
     "To" : "אל",
-    "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
     "Cc" : "עותק",
     "Bcc" : "עותק נסתר",
     "Subject" : "נושא",
-    "Subject …" : "נושא…",
     "This message came from a noreply address so your reply will probably not be read." : "הודעה זו הגיעה מכתובת שאינה מיועדת למענה (noreply) ולכן כנראה שהתגובה שלך לא תיקרא.",
     "The following recipients do not have a PGP key: {recipients}." : "לנמענים הבאים אין מפתח PGP‏: {recipients}.",
-    "Write message …" : "כתיבת הודעה…",
-    "Saving draft …" : "הטיוטה נשמרת…",
     "Draft saved" : "הטיוטה נשמרה",
     "Enable formatting" : "הפעלת עיצוב",
     "Upload attachment" : "העלאת קובץ מצורף",
@@ -172,7 +168,6 @@ OC.L10N.register(
     "Collapse folders" : "קיווץ תיקיות",
     "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
-    "Loading …" : "בטעינה",
     "Delete folder" : "מחק תיקייה",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
     "Mark all as read" : "סימון הכול כנקרא",
@@ -199,13 +194,11 @@ OC.L10N.register(
     "Tags" : "תגיות",
     "Select tags" : "בחירת תגיות",
     "Custom" : "מותאם אישית",
-    "Signature …" : "חתימה…",
     "Save signature" : "שמירת החתימה",
     "Message source" : "מקור ההודעה",
     "Tag already exists" : "תגית כבר קיימת",
     "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
     "Add tag" : "הוספת תגית",
-    "Saving tag …" : "התגית נשמרת…",
     "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
     "Not found" : "לא נמצא",
     "Reply to sender only" : "להגיב לשולח בלבד",
@@ -284,6 +277,13 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
     "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
-    "Trusted senders" : "שולחים מהימנים"
+    "Trusted senders" : "שולחים מהימנים",
+    "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
+    "Subject …" : "נושא…",
+    "Write message …" : "כתיבת הודעה…",
+    "Saving draft …" : "הטיוטה נשמרת…",
+    "Loading …" : "בטעינה",
+    "Signature …" : "חתימה…",
+    "Saving tag …" : "התגית נשמרת…"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
