@@ -70,7 +70,6 @@ OC.L10N.register(
     "Shared with me" : "Dijeljeno sa mnom",
     "Security" : "Sigurnost",
     "Manage certificates" : "Upravljanje vjerodajnicama",
-    "About" : "Informacije",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Compose new message" : "Sastavi novu poruku",
     "Newer message" : "Novija poruka",
@@ -82,20 +81,17 @@ OC.L10N.register(
     "Search" : "Traži",
     "Send" : "Pošalji",
     "Refresh" : "Osvježi",
+    "About" : "Informacije",
     "Ok" : "U redu",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
     "From" : "Od",
     "Select account" : "Odaberi račun",
     "To" : "Do",
-    "Contact or email address …" : "Kontakt ili adresa e-pošte...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Predmet",
-    "Subject …" : "Naslov...",
     "This message came from a noreply address so your reply will probably not be read." : "Ova je poruka poslana s adrese na koju se ne može odgovoriti pa vaš odgovor vjerojatno nitko neće pročitati.",
     "The following recipients do not have a PGP key: {recipients}." : "Sljedeći primatelji nemaju PGP-ključ: {recipients}.",
-    "Write message …" : "Napiši poruku...",
-    "Saving draft …" : "Spremanje skice...",
     "Draft saved" : "Skica je spremljena",
     "Enable formatting" : "Omogući oblikovanje",
     "Upload attachment" : "Otpremi privitak",
@@ -210,7 +206,6 @@ OC.L10N.register(
     "Collapse folders" : "Sakrij mape",
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
-    "Loading …" : "Učitavanje…",
     "The folder and all messages in it will be deleted." : "Izbrisat će se mapa i sve poruke.",
     "Delete folder" : "Izbriši mapu",
     "Delete folder {name}" : "Izbriši mapu {name}",
@@ -237,7 +232,6 @@ OC.L10N.register(
     "Add to Contact" : "Dodaj kontaktu",
     "New Contact" : "Novi kontakt",
     "Copy to clipboard" : "Kopiraj u međuspremnik",
-    "Contact name …" : "Naziv kontakta…",
     "Add" : "Dodaj",
     "Show less" : "Prikaži manje",
     "Show more" : "Prikaži više",
@@ -253,18 +247,15 @@ OC.L10N.register(
     "Sieve Password" : "Sieve zaporka",
     "Save sieve settings" : "Spremi postavke za Sieve",
     "Save sieve script" : "Spremi Sieve skriptu",
-    "Signature …" : "Potpis...",
     "Save signature" : "Spremi potpis",
     "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
     "Message source" : "Izvor poruke",
     "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
-    "Saving new tag name …" : "Spremanje novog naziva oznake…",
     "Delete tag" : "Izbriši oznaku",
     "Tag already exists" : "Oznaka već postoji",
     "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
     "Add default tags" : "Dodaj zadane oznake",
     "Add tag" : "Dodaj oznaku",
-    "Saving tag …" : "Spremanje oznake...",
     "Could not load your message thread" : "Učitavanje vaše dretve poruka nije uspjelo",
     "Not found" : "Nije pronađeno",
     "Unsubscribe" : "Otkaži pretplatu",
@@ -391,6 +382,15 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
     "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
-    "Trusted senders" : "Pouzdani pošiljatelji"
+    "Trusted senders" : "Pouzdani pošiljatelji",
+    "Contact or email address …" : "Kontakt ili adresa e-pošte...",
+    "Subject …" : "Naslov...",
+    "Write message …" : "Napiši poruku...",
+    "Saving draft …" : "Spremanje skice...",
+    "Loading …" : "Učitavanje…",
+    "Contact name …" : "Naziv kontakta…",
+    "Signature …" : "Potpis...",
+    "Saving new tag name …" : "Spremanje novog naziva oznake…",
+    "Saving tag …" : "Spremanje oznake..."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
