@@ -108,7 +108,6 @@ OC.L10N.register(
     "Shared with me" : "Megosztva velem",
     "Security" : "Biztonság",
     "Manage certificates" : "Tanúsítványok kezelése",
-    "About" : "Névjegy",
     "Keyboard shortcuts" : "Gyorsbillentyűk",
     "Compose new message" : "Új üzenet írása",
     "Newer message" : "Újabb üzenet",
@@ -120,6 +119,7 @@ OC.L10N.register(
     "Search" : "Keresés",
     "Send" : "Küldés",
     "Refresh" : "Frissítés",
+    "About" : "Névjegy",
     "Ok" : "Rendben",
     "No certificate" : "Nincs tanúsítvány",
     "Certificate updated" : "Tanúsítvány frissítve",
@@ -142,16 +142,12 @@ OC.L10N.register(
     "Select account" : "Fiók kiválasztása",
     "To" : "Címzett",
     "Select recipient" : "Válasszon címzettet",
-    "Contact or email address …" : "Címzett vagy e-mail-cím…",
     "Cc" : "Másolat",
     "Bcc" : "Rejtett másolat",
     "Subject" : "Tárgy",
-    "Subject …" : "Tárgy…",
     "This message came from a noreply address so your reply will probably not be read." : "Vegye figyelembe, hogy a levél egy „ne válaszoljon” címről érkezett, így a válaszát valószínűleg nem fogják elolvasni.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "A következő címzettek nem rendelkeznek S/MIME-tanúsítvánnyal: {recipents}",
     "The following recipients do not have a PGP key: {recipients}." : "A következő címzettek nem rendelkeznek PGP kulccsal: {recipents}",
-    "Write message …" : "Üzenet írása…",
-    "Saving draft …" : "Piszkozat mentése…",
     "Error saving draft" : "Hiba a piszkozat mentése során",
     "Draft saved" : "Vázlat elmentve",
     "Save draft" : "Piszkozat mentése",
@@ -280,7 +276,6 @@ OC.L10N.register(
     "Today" : "Ma",
     "Last week" : "Előző hét",
     "Last month" : "Előző hónap",
-    "Loading messages …" : "Üzenetek betöltése…",
     "Choose target folder" : "Válasszon célmappát",
     "No more submailboxes in here" : "Nem találhatók további alpostafiókok",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Az üzeneteket automatikusan fontosként jelöli meg az alapján, hogy mely üzenetekre reagált, vagy jelölt meg fontosként. Kezdetben lehet, hogy kézzel megváltoztatnia a fontosságot és ezzel kell tanítania a rendszert, de ez az idő múlásával javulni fog.",
@@ -342,7 +337,7 @@ OC.L10N.register(
     "Collapse folders" : "Mappák összecsukása",
     "_{total} message_::_{total} messages_" : ["{total} üzenet","{total} üzenet"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} olvasatlan az összesen {total} üzenetből","{unread} olvasatlan az összesen {total} üzenetből"],
-    "Loading …" : "Betöltés…",
+    "Loading …" : "Betöltés…",
     "All messages in mailbox will be deleted." : "A postaládában lévő összes üzenet végleges törlésre kerül.",
     "Clear mailbox {name}" : "A(z) {name} postaláda ürítése",
     "Delete folder" : "Mappa törlése",
@@ -393,7 +388,6 @@ OC.L10N.register(
     "Add to Contact" : "Hozzáadás a Névjegyekhez",
     "New Contact" : "Új névjegy",
     "Copy to clipboard" : "Másolás a vágólapra",
-    "Contact name …" : "Névjegyhez tartozó név…",
     "Add" : "Hozzáadás",
     "Show less" : "Kevesebb megjelenítése",
     "Show more" : "Több megjelenítése",
@@ -420,14 +414,12 @@ OC.L10N.register(
     "Save sieve settings" : "Levélszűrő beállítások mentése",
     "The syntax seems to be incorrect:" : "A szintaxis helytelennek tűnik:",
     "Save sieve script" : "Levélszűrő parancsfájl mentése",
-    "Signature …" : "Aláírás…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Az aláírás 2 MB-nál nagyobb. Ez hatással lehet a szerkesztő teljesítményére",
     "Save signature" : "Aláírás mentése",
     "Place signature above quoted text" : "Az aláírás az idézett szöveg fölé helyezése",
     "Message source" : "Üzenet forrása",
     "An error occurred, unable to rename the tag." : "Hiba történt, a címke nem nevezhető át",
     "Edit name or color" : "Név vagy szín szerkesztése",
-    "Saving new tag name …" : "Új címkenév mentése…",
     "Delete tag" : "Címke törlése",
     "Set tag" : "Címke beállítása",
     "Unset tag" : "Címke eltávolítása",
@@ -436,7 +428,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "HIba történt, a címke nem hozható létre.",
     "Add default tags" : "Alapértelmezett címkék hozzáadása",
     "Add tag" : "Címke hozzáadása",
-    "Saving tag …" : "Címke mentése…",
     "Task created" : "Feladat létrehozva",
     "Could not create task" : "Nem sikerült létrehozni a feladatot",
     "No calendars with task list support" : "Nincs feladatlista támogatással rendelkező naptár",
@@ -647,6 +638,16 @@ OC.L10N.register(
     "Register as application for mail links" : "Alkalmazás beállítása a levélhivatkozásokhoz",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Engedélyezés az alkalmazásnak, hogy az adatokat gyűjtsön az interakcióiról. Az adatok alapján az alkalmazás alkalmazkodni fog a használati szokásaihoz. Az adatok helyben lesznek tárolva.",
     "Trusted senders" : "Megbízható küldők",
-    "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése"
+    "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése",
+    "Contact or email address …" : "Címzett vagy e-mail-cím…",
+    "Subject …" : "Tárgy…",
+    "Write message …" : "Üzenet írása…",
+    "Saving draft …" : "Piszkozat mentése…",
+    "Loading messages …" : "Üzenetek betöltése…",
+    "Loading …" : "Betöltés…",
+    "Contact name …" : "Névjegyhez tartozó név…",
+    "Signature …" : "Aláírás…",
+    "Saving new tag name …" : "Új címkenév mentése…",
+    "Saving tag …" : "Címke mentése…"
 },
 "nplurals=2; plural=(n != 1);");
