@@ -110,7 +110,6 @@ OC.L10N.register(
     "Security" : "Security",
     "S/MIME" : "S/MIME",
     "Mailvelope" : "Mailvelope",
-    "About" : "About",
     "Keyboard shortcuts" : "Keyboard shortcuts",
     "Compose new message" : "Compose new message",
     "Newer message" : "Newer message",
@@ -122,6 +121,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Send",
     "Refresh" : "Refresh",
+    "About" : "About",
     "Ok" : "Ok",
     "No certificate" : "No certificate",
     "Certificate updated" : "Certificate updated",
@@ -143,16 +143,12 @@ OC.L10N.register(
     "From" : "From",
     "Select account" : "Select account",
     "To" : "To",
-    "Contact or email address …" : "Contact or email address …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Subject",
-    "Subject …" : "Subject …",
     "This message came from a noreply address so your reply will probably not be read." : "This message came from a noreply address so your reply will probably not be read.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "The following recipients do not have a S/MIME certificate: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "The following recipients do not have a PGP key: {recipients}.",
-    "Write message …" : "Write message …",
-    "Saving draft …" : "Saving draft …",
     "Error saving draft" : "Error saving draft",
     "Draft saved" : "Draft saved",
     "Save draft" : "Save draft",
@@ -279,7 +275,6 @@ OC.L10N.register(
     "Yesterday" : "გუშინ",
     "Last week" : "Last week",
     "Last month" : "Last month",
-    "Loading messages …" : "Loading messages …",
     "Choose target folder" : "Choose target folder",
     "No more submailboxes in here" : "No more submailboxes in here",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
@@ -336,7 +331,6 @@ OC.L10N.register(
     "Move down" : "Move down",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
-    "Loading …" : "Loading …",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
     "Delete folder" : "Delete folder",
@@ -387,7 +381,6 @@ OC.L10N.register(
     "Add to Contact" : "Add to Contact",
     "New Contact" : "New Contact",
     "Copy to clipboard" : "Copy to clipboard",
-    "Contact name …" : "Contact name …",
     "Add" : "Add",
     "Show less" : "Show less",
     "Show more" : "Show more",
@@ -417,14 +410,12 @@ OC.L10N.register(
     "Save sieve settings" : "Save sieve settings",
     "The syntax seems to be incorrect:" : "The syntax seems to be incorrect:",
     "Save sieve script" : "Save sieve script",
-    "Signature …" : "Signature …",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
     "Save signature" : "Save signature",
     "Place signature above quoted text" : "Place signature above quoted text",
     "Message source" : "Message source",
     "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
     "Edit name or color" : "Edit name or color",
-    "Saving new tag name …" : "Saving new tag name …",
     "Delete tag" : "Delete tag",
     "Set tag" : "Set tag",
     "Unset tag" : "Unset tag",
@@ -434,7 +425,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
     "Add default tags" : "Add default tags",
     "Add tag" : "Add tag",
-    "Saving tag …" : "Saving tag …",
     "Task created" : "Task created",
     "Could not create task" : "Could not create task",
     "No calendars with task list support" : "No calendars with task list support",
@@ -643,6 +633,16 @@ OC.L10N.register(
     "Data collection consent" : "Data collection consent",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
     "Trusted senders" : "Trusted senders",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates"
+    "Manage S/MIME certificates" : "Manage S/MIME certificates",
+    "Contact or email address …" : "Contact or email address …",
+    "Subject …" : "Subject …",
+    "Write message …" : "Write message …",
+    "Saving draft …" : "Saving draft …",
+    "Loading messages …" : "Loading messages …",
+    "Loading …" : "Loading …",
+    "Contact name …" : "Contact name …",
+    "Signature …" : "Signature …",
+    "Saving new tag name …" : "Saving new tag name …",
+    "Saving tag …" : "Saving tag …"
 },
 "nplurals=2; plural=(n!=1);");
