@@ -16,12 +16,12 @@ OC.L10N.register(
     "List" : "Tabdart",
     "Newest first" : "Imaynuten d imezwura",
     "Oldest first" : "Iqbuṛen d imezwura",
-    "About" : "Γef",
     "Keyboard shortcuts" : "Inegzumen n unasiw",
     "Delete" : "Kkes",
     "Search" : "Nadi",
     "Send" : "Tuzna",
     "Refresh" : "Sismeḍ",
+    "About" : "Γef",
     "Ok" : "Ih",
     "Choose" : "Fren",
     "Confirm" : "Serggeg",
@@ -45,7 +45,6 @@ OC.L10N.register(
     "Remove account" : "Kkes amiḍan",
     "Add folder" : "Rnu akaram",
     "Folder name" : "Isem n ukaram",
-    "Loading …" : "Asali ...",
     "Delete folder" : "Kkes akaram",
     "Rename" : "Beddel isem",
     "Draft" : "Arewway",
@@ -75,6 +74,7 @@ OC.L10N.register(
     "Nextcloud Mail" : "Imayl n Nextcloud",
     "Message sent" : "Izen yettwazen",
     "Continue to %s" : "Kemmel ar %s",
-    "Accounts" : "Imiḍanen"
+    "Accounts" : "Imiḍanen",
+    "Loading …" : "Asali ..."
 },
 "nplurals=2; plural=(n != 1);");
