@@ -105,8 +105,6 @@ OC.L10N.register(
     "Privacy and security" : "Приватност и безбедност",
     "Security" : "Безбедност",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Означете ги надворешните е-адреси со овозможување на оваа функција, управувајте со вашите внатрешни адреси и домени за да се осигурате дека препознаените контакти остануваат необележани.",
-    "About" : "За",
-    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Compose new message" : "Состави нова порака",
     "Newer message" : "Понови пораки",
@@ -118,6 +116,8 @@ OC.L10N.register(
     "Search" : "Барај",
     "Send" : "Прати",
     "Refresh" : "Освежи",
+    "About" : "За",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
     "Ok" : "Во ред",
     "No certificate" : "Нема сертификат",
     "Certificate updated" : "Сертификатот е ажуриран",
@@ -140,16 +140,12 @@ OC.L10N.register(
     "Select account" : "Избете сметка",
     "To" : "До",
     "Select recipient" : "Избери примач",
-    "Contact or email address …" : "Контакт или е-пошта адреса ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "Наслов",
-    "Subject …" : "Наслов ...",
     "This message came from a noreply address so your reply will probably not be read." : "Оваа порака е испратена од адреса што е назначена без одговор, така што вашиот одговор веројатно нема да биде прочитан.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Следниве примачи не поседуваат S/MIME сертификат: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Следниве примачи не поседуваат PGP клуч: {recipients}.",
-    "Write message …" : "Напиши порака ...",
-    "Saving draft …" : "Зачувување како нацрт ...",
     "Error saving draft" : "Грешка при зачувување на шаблон",
     "Draft saved" : "Нацртот е зачуван",
     "Save draft" : "Зачувај примерок",
@@ -245,7 +241,6 @@ OC.L10N.register(
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
     "Today" : "Денес",
     "Last week" : "Минатата недела",
-    "Loading messages …" : "Вчитување пораки ...",
     "Choose target folder" : "Избери папка",
     "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
@@ -297,7 +292,7 @@ OC.L10N.register(
     "Collapse folders" : "Сокриј ги папките",
     "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
-    "Loading …" : "Се вчитува…",
+    "Loading …" : "Се вчитува …",
     "Clear mailbox {name}" : "Исчисти сандаче {name}",
     "The folder and all messages in it will be deleted." : "Папката и сите пораки во неа ќе бидат избришани.",
     "Delete folder" : "Избриши папка",
@@ -342,7 +337,6 @@ OC.L10N.register(
     "Add to Contact" : "Додади во контакти",
     "New Contact" : "Нов контакт",
     "Copy to clipboard" : "Копирај во клипборд",
-    "Contact name …" : "Име на контакт ...",
     "Add" : "Додади",
     "Show less" : "Помалку",
     "Show more" : "Прикажи повеќе",
@@ -367,18 +361,15 @@ OC.L10N.register(
     "Sieve Password" : "Sieve лозинка",
     "Save sieve settings" : "Зачувај sieve параметри",
     "Save sieve script" : "Зачувај sieve скрипта",
-    "Signature …" : "Потпис ...",
     "Save signature" : "Зачувај потпис",
     "Place signature above quoted text" : "Постави го потписот над цитираниот текст",
     "Message source" : "Извор на пораката",
     "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
-    "Saving new tag name …" : "Зачувување на ново име на ознака ...",
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
     "Tag already exists" : "Тагот веќе постои",
     "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
     "Add default tags" : "Додади стандардни ознаки",
     "Add tag" : "Додади ознака",
-    "Saving tag …" : "Зачувување ознака …",
     "Could not load your message thread" : "Неможат да се преземат информации за пораката",
     "Not found" : "Не е пронајдено",
     "Reply all" : "Одговори на сите",
@@ -490,6 +481,16 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
     "Trusted senders" : "Доверливи испраќачи",
     "Internal addresses" : "Внатрешни адреси",
-    "Manage S/MIME certificates" : "Управувај со S/MIME серификатите"
+    "Manage S/MIME certificates" : "Управувај со S/MIME серификатите",
+    "Contact or email address …" : "Контакт или е-пошта адреса ...",
+    "Subject …" : "Наслов ...",
+    "Write message …" : "Напиши порака ...",
+    "Saving draft …" : "Зачувување како нацрт ...",
+    "Loading messages …" : "Вчитување пораки ...",
+    "Loading …" : "Се вчитува…",
+    "Contact name …" : "Име на контакт ...",
+    "Signature …" : "Потпис ...",
+    "Saving new tag name …" : "Зачувување на ново име на ознака ...",
+    "Saving tag …" : "Зачувување ознака …"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
