@@ -130,7 +130,6 @@ OC.L10N.register(
     "Manage certificates" : "Administrer sertifikat",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Assistanse funksjoner",
-    "About" : "Om",
     "Keyboard shortcuts" : "Tastatursnarveier",
     "Compose new message" : "Lag ny melding",
     "Newer message" : "Nyere melding",
@@ -142,6 +141,7 @@ OC.L10N.register(
     "Search" : "Søk",
     "Send" : "Send",
     "Refresh" : "Oppdater",
+    "About" : "Om",
     "Ok" : "Ok",
     "No certificate" : "Ingen sertifikat",
     "Certificate updated" : "Sertifikat oppdatert",
@@ -167,16 +167,12 @@ OC.L10N.register(
     "To" : "Til",
     "Cc/Bcc" : "Kopi/Blindkopi",
     "Select recipient" : "Velg mottaker",
-    "Contact or email address …" : "Kontakt eller e-post adresse ...",
     "Cc" : "Kopi",
     "Bcc" : "Blindkopi",
     "Subject" : "Emne",
-    "Subject …" : "Emne ...",
     "This message came from a noreply address so your reply will probably not be read." : "Denne meldingen kom fra en noreply-adresse, så svaret ditt vil sannsynligvis ikke bli lest.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "Følgende mottakere har ikke et S/MIME-sertifikat: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Følgende mottakere har ikke en PGP-nøkkel: {recipients}.",
-    "Write message …" : "Skriv melding ...",
-    "Saving draft …" : "Lagrer kladd…",
     "Error saving draft" : "Feil under lagring av utkast",
     "Draft saved" : "Kladd ble lagret",
     "Save draft" : "Lagre utkast",
@@ -311,7 +307,6 @@ OC.L10N.register(
     "Yesterday" : "Igår",
     "Last week" : "Forrige uke",
     "Last month" : "Forrige måned",
-    "Loading messages …" : "Laster meldinger ...",
     "Choose target folder" : "Velg målmappe",
     "No more submailboxes in here" : "Ingen flere underpostbokser her",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meldinger blir automatisk merket som viktige basert på hvilke meldinger du har interagert med eller merket som viktige. I begynnelsen må du kanskje endre viktigheten manuelt for å lære systemet, men det vil forbedres over tid.",
@@ -379,7 +374,6 @@ OC.L10N.register(
     "Collapse folders" : "Skjul mapper",
     "_{total} message_::_{total} messages_" : ["{total} melding","{total} meldinger"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulest av {total}","{unread} uleste av {total}"],
-    "Loading …" : "Laster...",
     "All messages in mailbox will be deleted." : "Alle meldinger i postkassen blir slettet.",
     "Clear mailbox {name}" : "Tøm postboks {name}",
     "Delete folder" : "Slett mappe",
@@ -437,7 +431,6 @@ OC.L10N.register(
     "Add to Contact" : "Legg til kontakt",
     "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopiert til utklippstavlen",
-    "Contact name …" : "Kontakt navn ...",
     "Add" : "Legg til",
     "Show less" : "Vis mindre",
     "Show more" : "Vis mer",
@@ -474,14 +467,12 @@ OC.L10N.register(
     "Save sieve settings" : "Lagre sieve innstillinger",
     "The syntax seems to be incorrect:" : "Syntaksen ser ut til å være feil:",
     "Save sieve script" : "Lagre sieve script",
-    "Signature …" : "Signatur ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Signaturen din er større enn 2 MB. Dette kan påvirke ytelsen til redigeringsprogrammet ditt.",
     "Save signature" : "Lagre signatur",
     "Place signature above quoted text" : "Plasser signatur over sitert tekst",
     "Message source" : "Melding kilde",
     "An error occurred, unable to rename the tag." : "Det oppsto en feil, kan ikke gi nytt navn til taggen.",
     "Edit name or color" : "Rediger navn eller farge",
-    "Saving new tag name …" : "Lagrer nytt tagnavn …",
     "Delete tag" : "Slett merke",
     "Set tag" : "Sett merkelapp",
     "Unset tag" : "Opphev merkelapp",
@@ -491,7 +482,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "Det oppsto en feil, kan ikke opprette taggen.",
     "Add default tags" : "Legg til standardtags",
     "Add tag" : "Legg til merkelapp",
-    "Saving tag …" : "Lagrer tag …",
     "Task created" : "Oppgave opprettet",
     "Could not create task" : "Kunne ikke opprette oppgave",
     "No calendars with task list support" : "Ingen kalendere med støtte for oppgavelister",
@@ -717,6 +707,16 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillat at appen samler inn data om interaksjonene dine. Basert på disse dataene vil appen tilpasse seg dine preferanser. Dataene vil kun bli lagret lokalt.",
     "Trusted senders" : "Pålitelige avsendere",
     "Internal addresses" : "Interne adresser",
-    "Manage S/MIME certificates" : "Administrer S/MIME-sertifikater"
+    "Manage S/MIME certificates" : "Administrer S/MIME-sertifikater",
+    "Contact or email address …" : "Kontakt eller e-post adresse ...",
+    "Subject …" : "Emne ...",
+    "Write message …" : "Skriv melding ...",
+    "Saving draft …" : "Lagrer kladd…",
+    "Loading messages …" : "Laster meldinger ...",
+    "Loading …" : "Laster...",
+    "Contact name …" : "Kontakt navn ...",
+    "Signature …" : "Signatur ...",
+    "Saving new tag name …" : "Lagrer nytt tagnavn …",
+    "Saving tag …" : "Lagrer tag …"
 },
 "nplurals=2; plural=(n != 1);");
