@@ -13,10 +13,10 @@ OC.L10N.register(
     "Go back" : "ආපසු යන්න",
     "Cancel" : "අවලංගු කරන්න",
     "General" : "සමාන්‍යය",
-    "About" : "පිළිබඳ",
     "Archive" : "සංරක්ෂණය",
     "Search" : "සොයන්න",
     "Send" : "යවන්න",
+    "About" : "පිළිබඳ",
     "Choose" : "තෝරන්න",
     "Confirm" : "තහවුරු කරන්න",
     "Favorite" : "ප්‍රියතම",
@@ -34,7 +34,6 @@ OC.L10N.register(
     "Translate" : "පරිවර්තනය",
     "Remove account" : "ගිණුම ඉවත් කරන්න",
     "Folder name" : "බහාලුමේ නම",
-    "Loading …" : "පූරණය වෙමින් …",
     "Mark all as read" : "සියල්ල කියවූ ලෙස සලකුණු කරන්න",
     "Reply" : "පිළිතුර",
     "Retry" : "නැවත උත්සාහ කරන්න",
@@ -53,6 +52,7 @@ OC.L10N.register(
     "Shares" : "බෙදාගැනීම්",
     "All" : "සියල්ල",
     "Favorites" : "ප්‍රියතම",
-    "Accounts" : "Accounts"
+    "Accounts" : "Accounts",
+    "Loading …" : "පූරණය වෙමින් …"
 },
 "nplurals=2; plural=(n != 1);");
