@@ -134,7 +134,6 @@ OC.L10N.register(
     "S/MIME" : "S / MIME",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "ياردەم ئىقتىدارلىرى",
-    "About" : "ھەققىدە",
     "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
     "Compose new message" : "يېڭى ئۇچۇر يېزىڭ",
     "Newer message" : "يېڭى ئۇچۇر",
@@ -146,6 +145,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "يوللا",
     "Refresh" : "يېڭىلا",
+    "About" : "ھەققىدە",
     "Ok" : "جەزملە",
     "No certificate" : "گۇۋاھنامە يوق",
     "Certificate updated" : "گۇۋاھنامە يېڭىلاندى",
@@ -171,16 +171,12 @@ OC.L10N.register(
     "To" : "To",
     "Cc/Bcc" : "Cc / Bcc",
     "Select recipient" : "تاپشۇرۇۋالغۇچىنى تاللاڭ",
-    "Contact or email address …" : "ئالاقىلىشىش ياكى ئېلېكترونلۇق خەت ئادرېسى…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
     "Subject" : "تېما",
-    "Subject …" : "تېما…",
     "This message came from a noreply address so your reply will probably not be read." : "بۇ ئۇچۇر ناتوغرا ئادرېستىن كەلگەن ، شۇڭا جاۋابىڭىز ئوقۇلماسلىقى مۇمكىن.",
     "The following recipients do not have a S/MIME certificate: {recipients}." : "تۆۋەندىكى تاپشۇرۇۋالغۇچىلارنىڭ S / MIME گۇۋاھنامىسى يوق: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "تۆۋەندىكى تاپشۇرۇۋالغۇچىلارنىڭ PGP ئاچقۇچى يوق: {recipients}.",
-    "Write message …" : "ئۇچۇر يېزىڭ…",
-    "Saving draft …" : "لايىھە تېجەش…",
     "Error saving draft" : "لايىھە تېجەشتە خاتالىق",
     "Draft saved" : "لايىھە ساقلاندى",
     "Save draft" : "لايىھەنى ساقلاڭ",
@@ -300,7 +296,6 @@ OC.L10N.register(
     "Yesterday" : "تۈنۈگۈن",
     "Last week" : "ئالدىنقى ھەپتە",
     "Last month" : "ئالدىنقى ئاي",
-    "Loading messages …" : "ئۇچۇرلارنى يۈكلەۋاتىدۇ…",
     "Choose target folder" : "نىشان ھۆججەت قىسقۇچىنى تاللاڭ",
     "No more submailboxes in here" : "بۇ يەردە باشقا خەت ساندۇقى يوق",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "سىز قايسى ئۇچۇرلار بىلەن ئالاقە قىلغان ياكى مۇھىم دەپ بەلگە قويۇلغان ئۇچۇرلار ئاپتوماتىك ھالدا مۇھىم دەپ بەلگە قىلىنىدۇ. باشتا سىز سىستېمىنى ئوقۇتۇشنىڭ مۇھىملىقىنى قولدا ئۆزگەرتىشىڭىز مۇمكىن ، ئەمما ۋاقىتنىڭ ئۆتۈشىگە ئەگىشىپ ياخشىلىنىدۇ.",
@@ -363,7 +358,6 @@ OC.L10N.register(
     "Saving" : "تېجەش",
     "Move up" : "يۆتكەڭ",
     "Move down" : "تۆۋەنگە يۆتكەڭ",
-    "Loading …" : "Loading…",
     "All messages in mailbox will be deleted." : "خەت ساندۇقىدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
     "Clear mailbox {name}" : "خەت ساندۇقىنى تازىلاش {name}",
     "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
@@ -423,7 +417,6 @@ OC.L10N.register(
     "Add to Contact" : "ئالاقىلىشىشكە قوشۇڭ",
     "New Contact" : "يېڭى ئالاقىلىشىش",
     "Copy to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈڭ",
-    "Contact name …" : "ئالاقىلىشىش ئىسمى…",
     "Add" : "قوش",
     "Show less" : "ئازراق كۆرسەت",
     "Show more" : "تېخىمۇ كۆپ كۆرسەت",
@@ -463,14 +456,12 @@ OC.L10N.register(
     "Save sieve settings" : "ئەلگەك تەڭشەكلىرىنى ساقلاڭ",
     "The syntax seems to be incorrect:" : "گرامماتىكىسى خاتادەك قىلىدۇ:",
     "Save sieve script" : "ئەلگەك قوليازمىسىنى ساقلاڭ",
-    "Signature …" : "ئىمزا…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "ئىمزاسىڭىز 2 MB دىن چوڭ. بۇ بەلكىم تەھرىرىڭىزنىڭ ئىقتىدارىغا تەسىر كۆرسىتىشى مۇمكىن.",
     "Save signature" : "ئىمزا ساقلاڭ",
     "Place signature above quoted text" : "ئىمزانى نەقىل ئېلىنغان تېكىستنىڭ ئۈستىگە قويۇڭ",
     "Message source" : "ئۇچۇر مەنبەسى",
     "An error occurred, unable to rename the tag." : "خەتكۈچنىڭ نامىنى ئۆزگەرتىشكە ئامالسىز قالغان.",
     "Edit name or color" : "ئىسىم ياكى رەڭنى تەھرىرلەڭ",
-    "Saving new tag name …" : "يېڭى خەتكۈچ نامىنى تېجەش…",
     "Delete tag" : "خەتكۈچنى ئۆچۈرۈڭ",
     "Set tag" : "بەلگە بەلگىلەڭ",
     "Unset tag" : "خەتكۈچنى تەڭشەش",
@@ -480,7 +471,6 @@ OC.L10N.register(
     "An error occurred, unable to create the tag." : "خەتكۈچ قۇرالماسلىقتا خاتالىق كۆرۈلدى.",
     "Add default tags" : "سۈكۈتتىكى بەلگىلەرنى قوشۇڭ",
     "Add tag" : "خەتكۈچ قوشۇڭ",
-    "Saving tag …" : "خەتكۈچنى ساقلاش…",
     "Task created" : "ۋەزىپە قۇرۇلدى",
     "Could not create task" : "ۋەزىپە قۇرالمىدى",
     "No calendars with task list support" : "ۋەزىپە تىزىملىكى قوللايدىغان كالېندار يوق",
@@ -717,6 +707,16 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "بۇ دېتالنىڭ ئۆز-ئارا تەسىرلىشىڭىزگە مۇناسىۋەتلىك ئۇچۇرلارنى توپلىشىغا يول قويۇڭ. بۇ سانلىق مەلۇماتلارغا ئاساسەن ، ئەپ سىزنىڭ مايىللىقىڭىزغا ماسلىشىدۇ. بۇ سانلىق مەلۇماتلار پەقەت يەرلىكتە ساقلىنىدۇ.",
     "Trusted senders" : "ئىشەنچلىك ئەۋەتكۈچىلەر",
     "Internal addresses" : "ئىچكى ئادرېس",
-    "Manage S/MIME certificates" : "S / MIME گۇۋاھنامىسىنى باشقۇرۇش"
+    "Manage S/MIME certificates" : "S / MIME گۇۋاھنامىسىنى باشقۇرۇش",
+    "Contact or email address …" : "ئالاقىلىشىش ياكى ئېلېكترونلۇق خەت ئادرېسى…",
+    "Subject …" : "تېما…",
+    "Write message …" : "ئۇچۇر يېزىڭ…",
+    "Saving draft …" : "لايىھە تېجەش…",
+    "Loading messages …" : "ئۇچۇرلارنى يۈكلەۋاتىدۇ…",
+    "Loading …" : "Loading…",
+    "Contact name …" : "ئالاقىلىشىش ئىسمى…",
+    "Signature …" : "ئىمزا…",
+    "Saving new tag name …" : "يېڭى خەتكۈچ نامىنى تېجەش…",
+    "Saving tag …" : "خەتكۈچنى ساقلاش…"
 },
 "nplurals=2; plural=(n != 1);");
